===========================
Django Simple Feedback Form
===========================

This `Django <http://djangoproject.com>`_ app has for provide simple form for sending mail forom users to admins your django-based site.

Requirements
------------

Django 3.0+


Installation and configuration
------------------------------

See `setup part`_ in documentation.

.. _setup part: https://django-simple-feedback-form.readthedocs.io/en/latest/setup.html

Usage
-----

See `usage part`_ in documentation.

.. _usage part: https://django-simple-feedback-form.readthedocs.io/en/latest/usage.html


License
-------

Licensed under BSD license. See `license link`_ in documentation.

.. _license link: LICENSE.rst